Index: jdct.h |
diff --git a/jdct.h b/jdct.h |
index 36374484f3d9cbf3e00fb581d9d7c3e0a355908f..faf8e1cf0315192edc114797cc6819a657781ec2 100644 |
--- a/jdct.h |
+++ b/jdct.h |
@@ -1,14 +1,17 @@ |
/* |
* jdct.h |
* |
+ * This file was part of the Independent JPEG Group's software: |
* Copyright (C) 1994-1996, Thomas G. Lane. |
- * This file is part of the Independent JPEG Group's software. |
- * For conditions of distribution and use, see the accompanying README file. |
+ * libjpeg-turbo Modifications: |
+ * Copyright (C) 2015, D. R. Commander. |
+ * For conditions of distribution and use, see the accompanying README.ijg |
+ * file. |
* |
* This include file contains common declarations for the forward and |
* inverse DCT modules. These declarations are private to the DCT managers |
* (jcdctmgr.c, jddctmgr.c) and the individual DCT algorithms. |
- * The individual DCT algorithms are kept in separate files to ease |
+ * The individual DCT algorithms are kept in separate files to ease |
* machine-dependent tuning (e.g., assembly coding). |
*/ |
@@ -16,7 +19,7 @@ |
/* |
* A forward DCT routine is given a pointer to a work area of type DCTELEM[]; |
* the DCT is to be performed in-place in that buffer. Type DCTELEM is int |
* for 8-bit samples, INT32 for 12-bit samples. (NOTE: Floating-point DCT |
* implementations use an array of type FAST_FLOAT, instead.) |
* The DCT inputs are expected to be signed (range +-CENTERJSAMPLE). |
* The DCT outputs are returned scaled up by a factor of 8; they therefore |
@@ -29,7 +32,7 @@ |
#if BITS_IN_JSAMPLE == 8 |
#ifndef WITH_SIMD |
-typedef int DCTELEM; /* 16 or 32 bits is fine */ |
+typedef int DCTELEM; /* 16 or 32 bits is fine */ |
typedef unsigned int UDCTELEM; |
typedef unsigned long long UDCTELEM2; |
#else |
@@ -38,8 +41,7 @@ typedef unsigned short UDCTELEM; |
typedef unsigned int UDCTELEM2; |
#endif |
#else |
-typedef INT32 DCTELEM; /* must have 32 bits */ |
-typedef UINT32 UDCTELEM; |
+typedef JLONG DCTELEM; /* must have 32 bits */ |
typedef unsigned long long UDCTELEM2; |
#endif |
@@ -64,10 +66,10 @@ typedef unsigned long long UDCTELEM2; |
typedef MULTIPLIER ISLOW_MULT_TYPE; /* short or int, whichever is faster */ |
#if BITS_IN_JSAMPLE == 8 |
typedef MULTIPLIER IFAST_MULT_TYPE; /* 16 bits is OK, use short if faster */ |
-#define IFAST_SCALE_BITS 2 /* fractional bits in scale factors */ |
+#define IFAST_SCALE_BITS 2 /* fractional bits in scale factors */ |
#else |
-typedef INT32 IFAST_MULT_TYPE; /* need 32 bits for scaled quantizers */ |
-#define IFAST_SCALE_BITS 13 /* fractional bits in scale factors */ |
+typedef JLONG IFAST_MULT_TYPE; /* need 32 bits for scaled quantizers */ |
+#define IFAST_SCALE_BITS 13 /* fractional bits in scale factors */ |
#endif |
typedef FAST_FLOAT FLOAT_MULT_TYPE; /* preferred floating type */ |
@@ -86,105 +88,79 @@ typedef FAST_FLOAT FLOAT_MULT_TYPE; /* preferred floating type */ |
#define RANGE_MASK (MAXJSAMPLE * 4 + 3) /* 2 bits wider than legal samples */ |
-/* Short forms of external names for systems with brain-damaged linkers. */ |
- |
-#ifdef NEED_SHORT_EXTERNAL_NAMES |
-#define jpeg_fdct_islow jFDislow |
-#define jpeg_fdct_ifast jFDifast |
-#define jpeg_fdct_float jFDfloat |
-#define jpeg_idct_islow jRDislow |
-#define jpeg_idct_ifast jRDifast |
-#define jpeg_idct_float jRDfloat |
-#define jpeg_idct_7x7 jRD7x7 |
-#define jpeg_idct_6x6 jRD6x6 |
-#define jpeg_idct_5x5 jRD5x5 |
-#define jpeg_idct_4x4 jRD4x4 |
-#define jpeg_idct_3x3 jRD3x3 |
-#define jpeg_idct_2x2 jRD2x2 |
-#define jpeg_idct_1x1 jRD1x1 |
-#define jpeg_idct_9x9 jRD9x9 |
-#define jpeg_idct_10x10 jRD10x10 |
-#define jpeg_idct_11x11 jRD11x11 |
-#define jpeg_idct_12x12 jRD12x12 |
-#define jpeg_idct_13x13 jRD13x13 |
-#define jpeg_idct_14x14 jRD14x14 |
-#define jpeg_idct_15x15 jRD15x15 |
-#define jpeg_idct_16x16 jRD16x16 |
-#endif /* NEED_SHORT_EXTERNAL_NAMES */ |
- |
/* Extern declarations for the forward and inverse DCT routines. */ |
-EXTERN(void) jpeg_fdct_islow JPP((DCTELEM * data)); |
-EXTERN(void) jpeg_fdct_ifast JPP((DCTELEM * data)); |
-EXTERN(void) jpeg_fdct_float JPP((FAST_FLOAT * data)); |
+EXTERN(void) jpeg_fdct_islow (DCTELEM *data); |
+EXTERN(void) jpeg_fdct_ifast (DCTELEM *data); |
+EXTERN(void) jpeg_fdct_float (FAST_FLOAT *data); |
EXTERN(void) jpeg_idct_islow |
- JPP((j_decompress_ptr cinfo, jpeg_component_info * compptr, |
- JCOEFPTR coef_block, JSAMPARRAY output_buf, JDIMENSION output_col)); |
+ (j_decompress_ptr cinfo, jpeg_component_info *compptr, |
+ JCOEFPTR coef_block, JSAMPARRAY output_buf, JDIMENSION output_col); |
EXTERN(void) jpeg_idct_ifast |
- JPP((j_decompress_ptr cinfo, jpeg_component_info * compptr, |
- JCOEFPTR coef_block, JSAMPARRAY output_buf, JDIMENSION output_col)); |
+ (j_decompress_ptr cinfo, jpeg_component_info *compptr, |
+ JCOEFPTR coef_block, JSAMPARRAY output_buf, JDIMENSION output_col); |
EXTERN(void) jpeg_idct_float |
- JPP((j_decompress_ptr cinfo, jpeg_component_info * compptr, |
- JCOEFPTR coef_block, JSAMPARRAY output_buf, JDIMENSION output_col)); |
+ (j_decompress_ptr cinfo, jpeg_component_info *compptr, |
+ JCOEFPTR coef_block, JSAMPARRAY output_buf, JDIMENSION output_col); |
EXTERN(void) jpeg_idct_7x7 |
- JPP((j_decompress_ptr cinfo, jpeg_component_info * compptr, |
- JCOEFPTR coef_block, JSAMPARRAY output_buf, JDIMENSION output_col)); |
+ (j_decompress_ptr cinfo, jpeg_component_info *compptr, |
+ JCOEFPTR coef_block, JSAMPARRAY output_buf, JDIMENSION output_col); |
EXTERN(void) jpeg_idct_6x6 |
- JPP((j_decompress_ptr cinfo, jpeg_component_info * compptr, |
- JCOEFPTR coef_block, JSAMPARRAY output_buf, JDIMENSION output_col)); |
+ (j_decompress_ptr cinfo, jpeg_component_info *compptr, |
+ JCOEFPTR coef_block, JSAMPARRAY output_buf, JDIMENSION output_col); |
EXTERN(void) jpeg_idct_5x5 |
- JPP((j_decompress_ptr cinfo, jpeg_component_info * compptr, |
- JCOEFPTR coef_block, JSAMPARRAY output_buf, JDIMENSION output_col)); |
+ (j_decompress_ptr cinfo, jpeg_component_info *compptr, |
+ JCOEFPTR coef_block, JSAMPARRAY output_buf, JDIMENSION output_col); |
EXTERN(void) jpeg_idct_4x4 |
- JPP((j_decompress_ptr cinfo, jpeg_component_info * compptr, |
- JCOEFPTR coef_block, JSAMPARRAY output_buf, JDIMENSION output_col)); |
+ (j_decompress_ptr cinfo, jpeg_component_info *compptr, |
+ JCOEFPTR coef_block, JSAMPARRAY output_buf, JDIMENSION output_col); |
EXTERN(void) jpeg_idct_3x3 |
- JPP((j_decompress_ptr cinfo, jpeg_component_info * compptr, |
- JCOEFPTR coef_block, JSAMPARRAY output_buf, JDIMENSION output_col)); |
+ (j_decompress_ptr cinfo, jpeg_component_info *compptr, |
+ JCOEFPTR coef_block, JSAMPARRAY output_buf, JDIMENSION output_col); |
EXTERN(void) jpeg_idct_2x2 |
- JPP((j_decompress_ptr cinfo, jpeg_component_info * compptr, |
- JCOEFPTR coef_block, JSAMPARRAY output_buf, JDIMENSION output_col)); |
+ (j_decompress_ptr cinfo, jpeg_component_info *compptr, |
+ JCOEFPTR coef_block, JSAMPARRAY output_buf, JDIMENSION output_col); |
EXTERN(void) jpeg_idct_1x1 |
- JPP((j_decompress_ptr cinfo, jpeg_component_info * compptr, |
- JCOEFPTR coef_block, JSAMPARRAY output_buf, JDIMENSION output_col)); |
+ (j_decompress_ptr cinfo, jpeg_component_info *compptr, |
+ JCOEFPTR coef_block, JSAMPARRAY output_buf, JDIMENSION output_col); |
EXTERN(void) jpeg_idct_9x9 |
- JPP((j_decompress_ptr cinfo, jpeg_component_info * compptr, |
- JCOEFPTR coef_block, JSAMPARRAY output_buf, JDIMENSION output_col)); |
+ (j_decompress_ptr cinfo, jpeg_component_info *compptr, |
+ JCOEFPTR coef_block, JSAMPARRAY output_buf, JDIMENSION output_col); |
EXTERN(void) jpeg_idct_10x10 |
- JPP((j_decompress_ptr cinfo, jpeg_component_info * compptr, |
- JCOEFPTR coef_block, JSAMPARRAY output_buf, JDIMENSION output_col)); |
+ (j_decompress_ptr cinfo, jpeg_component_info *compptr, |
+ JCOEFPTR coef_block, JSAMPARRAY output_buf, JDIMENSION output_col); |
EXTERN(void) jpeg_idct_11x11 |
- JPP((j_decompress_ptr cinfo, jpeg_component_info * compptr, |
- JCOEFPTR coef_block, JSAMPARRAY output_buf, JDIMENSION output_col)); |
+ (j_decompress_ptr cinfo, jpeg_component_info *compptr, |
+ JCOEFPTR coef_block, JSAMPARRAY output_buf, JDIMENSION output_col); |
EXTERN(void) jpeg_idct_12x12 |
- JPP((j_decompress_ptr cinfo, jpeg_component_info * compptr, |
- JCOEFPTR coef_block, JSAMPARRAY output_buf, JDIMENSION output_col)); |
+ (j_decompress_ptr cinfo, jpeg_component_info *compptr, |
+ JCOEFPTR coef_block, JSAMPARRAY output_buf, JDIMENSION output_col); |
EXTERN(void) jpeg_idct_13x13 |
- JPP((j_decompress_ptr cinfo, jpeg_component_info * compptr, |
- JCOEFPTR coef_block, JSAMPARRAY output_buf, JDIMENSION output_col)); |
+ (j_decompress_ptr cinfo, jpeg_component_info *compptr, |
+ JCOEFPTR coef_block, JSAMPARRAY output_buf, JDIMENSION output_col); |
EXTERN(void) jpeg_idct_14x14 |
- JPP((j_decompress_ptr cinfo, jpeg_component_info * compptr, |
- JCOEFPTR coef_block, JSAMPARRAY output_buf, JDIMENSION output_col)); |
+ (j_decompress_ptr cinfo, jpeg_component_info *compptr, |
+ JCOEFPTR coef_block, JSAMPARRAY output_buf, JDIMENSION output_col); |
EXTERN(void) jpeg_idct_15x15 |
- JPP((j_decompress_ptr cinfo, jpeg_component_info * compptr, |
- JCOEFPTR coef_block, JSAMPARRAY output_buf, JDIMENSION output_col)); |
+ (j_decompress_ptr cinfo, jpeg_component_info *compptr, |
+ JCOEFPTR coef_block, JSAMPARRAY output_buf, JDIMENSION output_col); |
EXTERN(void) jpeg_idct_16x16 |
- JPP((j_decompress_ptr cinfo, jpeg_component_info * compptr, |
- JCOEFPTR coef_block, JSAMPARRAY output_buf, JDIMENSION output_col)); |
+ (j_decompress_ptr cinfo, jpeg_component_info *compptr, |
+ JCOEFPTR coef_block, JSAMPARRAY output_buf, JDIMENSION output_col); |
/* |
* Macros for handling fixed-point arithmetic; these are used by many |
* but not all of the DCT/IDCT modules. |
* |
* All values are expected to be of type INT32. |
* Fractional constants are scaled left by CONST_BITS bits. |
* CONST_BITS is defined within each module using these macros, |
* and may differ from one module to the next. |
*/ |
-#define ONE ((INT32) 1) |
+#define ONE ((JLONG) 1) |
#define CONST_SCALE (ONE << CONST_BITS) |
/* Convert a positive real constant to an integer scaled by CONST_SCALE. |
@@ -192,16 +168,16 @@ EXTERN(void) jpeg_idct_16x16 |
* thus causing a lot of useless floating-point operations at run time. |
*/ |
#define FIX(x) ((INT32) ((x) * CONST_SCALE + 0.5)) |
/* Descale and correctly round an INT32 value that's scaled by N bits. |
* We assume RIGHT_SHIFT rounds towards minus infinity, so adding |
* the fudge factor is correct for either sign of X. |
*/ |
#define DESCALE(x,n) RIGHT_SHIFT((x) + (ONE << ((n)-1)), n) |
/* Multiply an INT32 variable by an INT32 constant to yield an INT32 result. |
* This macro is used only when the two inputs will actually be no more than |
* 16 bits wide, so that a 16x16->32 bit multiply can be used instead of a |
* full 32x32 multiply. This provides a useful speedup on many machines. |
@@ -210,23 +186,23 @@ EXTERN(void) jpeg_idct_16x16 |
* correct combination of casts. |
*/ |
-#ifdef SHORTxSHORT_32 /* may work if 'int' is 32 bits */ |
+#ifdef SHORTxSHORT_32 /* may work if 'int' is 32 bits */ |
#define MULTIPLY16C16(var,const) (((INT16) (var)) * ((INT16) (const))) |
#endif |
-#ifdef SHORTxLCONST_32 /* known to work with Microsoft C 6.0 */ |
-#define MULTIPLY16C16(var,const) (((INT16) (var)) * ((INT32) (const))) |
+#ifdef SHORTxLCONST_32 /* known to work with Microsoft C 6.0 */ |
+#define MULTIPLY16C16(var,const) (((INT16) (var)) * ((JLONG) (const))) |
#endif |
-#ifndef MULTIPLY16C16 /* default definition */ |
+#ifndef MULTIPLY16C16 /* default definition */ |
#define MULTIPLY16C16(var,const) ((var) * (const)) |
#endif |
/* Same except both inputs are variables. */ |
-#ifdef SHORTxSHORT_32 /* may work if 'int' is 32 bits */ |
+#ifdef SHORTxSHORT_32 /* may work if 'int' is 32 bits */ |
#define MULTIPLY16V16(var1,var2) (((INT16) (var1)) * ((INT16) (var2))) |
#endif |
-#ifndef MULTIPLY16V16 /* default definition */ |
+#ifndef MULTIPLY16V16 /* default definition */ |
#define MULTIPLY16V16(var1,var2) ((var1) * (var2)) |
#endif |
@@ -16,7 +19,7 @@ |
* A forward DCT routine is given a pointer to a work area of type DCTELEM[]; |
* the DCT is to be performed in-place in that buffer. Type DCTELEM is int |
- * for 8-bit samples, INT32 for 12-bit samples. (NOTE: Floating-point DCT |
+ * for 8-bit samples, JLONG for 12-bit samples. (NOTE: Floating-point DCT |
* implementations use an array of type FAST_FLOAT, instead.) |
* The DCT inputs are expected to be signed (range +-CENTERJSAMPLE). |
@@ -86,105 +88,79 @@ typedef FAST_FLOAT FLOAT_MULT_TYPE; /* preferred floating type */ |
* but not all of the DCT/IDCT modules. |
* |
- * All values are expected to be of type INT32. |
+ * All values are expected to be of type JLONG. |
* Fractional constants are scaled left by CONST_BITS bits. |
* CONST_BITS is defined within each module using these macros, |
@@ -192,16 +168,16 @@ EXTERN(void) jpeg_idct_16x16 |
* thus causing a lot of useless floating-point operations at run time. |
*/ |
-#define FIX(x) ((INT32) ((x) * CONST_SCALE + 0.5)) |
+#define FIX(x) ((JLONG) ((x) * CONST_SCALE + 0.5)) |
-/* Descale and correctly round an INT32 value that's scaled by N bits. |
+/* Descale and correctly round a JLONG value that's scaled by N bits. |
* We assume RIGHT_SHIFT rounds towards minus infinity, so adding |
* the fudge factor is correct for either sign of X. |
@@ -192,16 +168,16 @@ EXTERN(void) jpeg_idct_16x16 |
*/ |
#define DESCALE(x,n) RIGHT_SHIFT((x) + (ONE << ((n)-1)), n) |
-/* Multiply an INT32 variable by an INT32 constant to yield an INT32 result. |
+/* Multiply a JLONG variable by a JLONG constant to yield a JLONG result. |
* This macro is used only when the two inputs will actually be no more than |
* 16 bits wide, so that a 16x16->32 bit multiply can be used instead of a |